==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/powerbi/kotlin/inputs/AzureSkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.powerbi.kotlin.inputs

import com.pulumi.azurenative.powerbi.inputs.AzureSkuArgs.builder
import com.pulumi.azurenative.powerbi.kotlin.enums.AzureSkuName
import com.pulumi.azurenative.powerbi.kotlin.enums.AzureSkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name SKU name
 * @property tier SKU tier
 */
public data class AzureSkuArgs(
    public val name: Output<Either<String, AzureSkuName>>,
    public val tier: Output<Either<String, AzureSkuTier>>,
) : ConvertibleToJava<com.pulumi.azurenative.powerbi.inputs.AzureSkuArgs> {
    override fun toJava(): com.pulumi.azurenative.powerbi.inputs.AzureSkuArgs =
        com.pulumi.azurenative.powerbi.inputs.AzureSkuArgs.builder()
            .name(
                name.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureSkuArgs].
 */
@PulumiTagMarker
public class AzureSkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, AzureSkuName>>? = null

    private var tier: Output<Either<String, AzureSkuTier>>? = null

    /**
     * @param value SKU name
     */
    @JvmName("deyinhgjlomlsbnr")
    public suspend fun name(`value`: Output<Either<String, AzureSkuName>>) {
        this.name = value
    }

    /**
     * @param value SKU tier
     */
    @JvmName("blhifmkagandaukr")
    public suspend fun tier(`value`: Output<Either<String, AzureSkuTier>>) {
        this.tier = value
    }

    /**
     * @param value SKU name
     */
    @JvmName("dqetymvpiqycakuw")
    public suspend fun name(`value`: Either<String, AzureSkuName>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU name
     */
    @JvmName("gyxmmvsqfdhxjryr")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AzureSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU name
     */
    @JvmName("mautjhgvokdeobca")
    public fun name(`value`: AzureSkuName) {
        val toBeMapped = Either.ofRight<String, AzureSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU tier
     */
    @JvmName("mlykhgsssntebesj")
    public suspend fun tier(`value`: Either<String, AzureSkuTier>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value SKU tier
     */
    @JvmName("gxeawmspibelreyu")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AzureSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value SKU tier
     */
    @JvmName("gsvdrjhscogsebwp")
    public fun tier(`value`: AzureSkuTier) {
        val toBeMapped = Either.ofRight<String, AzureSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): AzureSkuArgs = AzureSkuArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tier = tier ?: throw PulumiNullFieldException("tier"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/powerbi/kotlin/inputs/AzureSkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.powerbi.kotlin.inputs

import com.pulumi.azurenative.powerbi.inputs.AzureSkuArgs.builder
import com.pulumi.azurenative.powerbi.kotlin.enums.AzureSkuName
import com.pulumi.azurenative.powerbi.kotlin.enums.AzureSkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name SKU name
 * @property tier SKU tier
 */
public data class AzureSkuArgs(
    public val name: Output<Either<String, AzureSkuName>>,
    public val tier: Output<Either<String, AzureSkuTier>>,
) : ConvertibleToJava<com.pulumi.azurenative.powerbi.inputs.AzureSkuArgs> {
    override fun toJava(): com.pulumi.azurenative.powerbi.inputs.AzureSkuArgs =
        com.pulumi.azurenative.powerbi.inputs.AzureSkuArgs.builder()
            .name(
                name.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureSkuArgs].
 */
@PulumiTagMarker
public class AzureSkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, AzureSkuName>>? = null

    private var tier: Output<Either<String, AzureSkuTier>>? = null

    /**
     * @param value SKU name
     */
    @JvmName("xxdtoufpmtqaoomi")
    public suspend fun name(`value`: Output<Either<String, AzureSkuName>>) {
        this.name = value
    }

    /**
     * @param value SKU tier
     */
    @JvmName("pjlsdocuvirwmxrl")
    public suspend fun tier(`value`: Output<Either<String, AzureSkuTier>>) {
        this.tier = value
    }

    /**
     * @param value SKU name
     */
    @JvmName("qygcrawdoyqjhqaj")
    public suspend fun name(`value`: Either<String, AzureSkuName>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU name
     */
    @JvmName("ypkqxeymgeaxwoxp")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AzureSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU name
     */
    @JvmName("oaruisyckltdpryu")
    public fun name(`value`: AzureSkuName) {
        val toBeMapped = Either.ofRight<String, AzureSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU tier
     */
    @JvmName("xuqiignnoiftxslf")
    public suspend fun tier(`value`: Either<String, AzureSkuTier>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value SKU tier
     */
    @JvmName("dwxnxmdfgxgotgan")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AzureSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value SKU tier
     */
    @JvmName("ovtbskuxweohtswi")
    public fun tier(`value`: AzureSkuTier) {
        val toBeMapped = Either.ofRight<String, AzureSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): AzureSkuArgs = AzureSkuArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tier = tier ?: throw PulumiNullFieldException("tier"),
    )
}
